@@ -324,6 +324,8 @@ echo "<td $kcal2><font size=1>*</font></td>";
 echo "<td $kcal2><font size=1>*</font></td>";
 echo "</tr>"; 
 
+$kazu = 0;
+
 while($s < $num){
    $YOUNAME = enco_rtrim(db_fetch_Result($result, $s, youname));
    $CNAME = enco_rtrim(db_fetch_Result($result, $s, cname));
@@ -367,6 +369,7 @@ while($s < $num){
       $pcol2 = $acol1;
       }
 
+   $kazu = $kazu + $moni;
 
    echo "<td $acol2><a target=_self href=$menucnew?BNAME=$BNAME&CNAME=$CNAME>$moni</td>";
    echo "<td $acol1><a target=_outwind href=$monitorwatch?FREE4=$BNAME>$CNAME</a></td>";
@@ -395,7 +398,7 @@ db_free_result($result);
 echo "<FORM METHOD=GET ACTION='userblock_cut_edit.php' target='insert'>";
 echo "<tr>";
 echo "<td>";
-echo "not";
+echo "$kazu";
 echo "<td\>";
 
 echo "<td align=center>";
@@ -504,6 +507,7 @@ echo "</FORM>";
 
 echo"</table>";
 
+echo "ƻ: $kazu  ֥å: $no";
 
 echo "\n";
 
