@@ -134,6 +134,13 @@ else{
 db_Close($conn);
 
 
+if(0 >= strlen($THREAD_MAX)){ $THREAD_MAX = 64; }
+if(0 >= strlen($TBUF_MAX)){ $TBUF_MAX = 64; }
+if(0 >= strlen($LIFE_ONOFF)){ $LIFE_ONOFF = 0; }
+if(0 >= strlen($MID_MAX)){ $MID_MAX = 64; }
+if(0 >= strlen($THREAD_LEN)){ $THREAD_LEN = 4; }
+if(0 >= strlen($MID_INT)){ $MID_INT = 300; }
+
 
 echo "\n";
 echo "<FORM METHOD=GET ACTION='config_up.php' target=config_up>";
