@@ -122,7 +122,7 @@ echo "</td></tr>";
 
 if(0 == strcmp($MONITOR, "PORT")){
    echo "<tr><td>";
-   echo "ƻץȥ롢ݡ DHW MYSQL ξΤ\n";
+   echo "ƻץȥ롢ݡ DHW MYSQL PGSQL ξΤ\n";
    echo "</td><td>";
    echo "<select size=1 name=PROTO>";
    echo "<option value=$PROTO selected>$PROTO";
@@ -137,6 +137,7 @@ if(0 == strcmp($MONITOR, "PORT")){
    echo "<option value=SSH>SSH";
    echo "<option value=DHW>DHW";
    echo "<option value=MYSQL>MYSQL";
+   echo "<option value=PGSQL>PGSQL";
    echo "<option value=SNTP>SNTP";
    echo "<option value=HOST>HOST";
    echo "<option value=NOT>NOT";
@@ -165,7 +166,7 @@ elseif(0 == strcmp($MONITOR, "PORT")){
    echo "<tr bgcolor='#D9DBED'><td>";
    echo "DHWξ硢¹ԥޥ\n";
    echo "HOSTξ硢IP\n";
-   echo "MYSQLξ硢꡼\n";
+   echo "MYSQL PGSQLξ硢꡼\n";
    echo "</td><td>";
    echo "<INPUT type='text' NAME=COM size='70' value='$COM'>";
    echo "</td></tr>";
