@@ -112,6 +112,15 @@
 #define MYSQL_1 "MYSQL ưǤ "
 #define MYSQL_2 "MYSQL ϰ۾֤ƤޤΥǡǤ "
 
+#define PGSQL_1 "PGSQL ưǤ "
+#define PGSQL_2 "PGSQL ϰ۾֤ƤޤΥǡǤ "
+
+#define PGSQL_ERR1 "postgreSQL³ʤ "
+#define PGSQL_ERR2 "Ф줿ʸ󤬶 "
+#define PGSQL_ERR3 "Фʱ򤫤 "
+#define PGSQL_ERR4 "顼ǤϤʤٹ򤫤 "
+#define PGSQL_ERR5 "̿ˤ륨顼򤫤 "
+#define PGSQL_ERR6 "䤤碌˳Կ0Ǥ "
 
 #define MONITOR_ERR_1  "ʤƻ°ꤷƤޤ㤨SNMPȤʤ饤ȤSNMP꤬Ƥޤ  "
 
