@@ -2,12 +2,14 @@
 
 #include<stdio.h>
 #include<stdlib.h>
+#include"sitar.h"
 
 int m_exit(int stat)
 {
 
 safe_exit("!!! The memory cannot be secured for the heap area. !!!");
 
+return 0;
 }
 
 
