@@ -27,17 +27,17 @@ for(count = 0; count <= gd.td.tcount; count ++){
    gd.td.fdstat[count] = 0;
    }
 
-if((gd.td.mutex_name=(char **)malloc(sizeof(char *) * (gd.td.tbufmax + 2)))==NULL){exit(1);}
-for(count = 0; count <= gd.td.tbufmax; count++){
-   if((gd.td.mutex_name[count]=(char *)calloc(2, sizeof(char)))==NULL){exit(1);}
-   gd.td.mutex_name[count] = safe_memcpy(gd.td.mutex_name[count], " \n", BUF_MAX); 
+// thread name
+if((gd.td.mutex_name=(char **)malloc(sizeof(char *) * (gd.td.tcount + 2)))==NULL){exit(1);}
+for(count = 0; count <= gd.td.tcount; count++){
+   if((gd.td.mutex_name[count]=(char *)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
    }
 
-if((gd.td.middle_name=(char **)malloc(sizeof(char *) * (B_MAX + 2)))==NULL){exit(1);}
-if((gd.td.middle_id=(char *)malloc(sizeof(char)*(B_MAX + 2)))==NULL){exit(1);}
-for(count = 0; count <= B_MAX; count++){
-   if((gd.td.middle_name[count]=(char *)calloc(2, sizeof(char)))==NULL){exit(1);}
-   gd.td.middle_name[count] = safe_memcpy(gd.td.middle_name[count], " \n", BUF_MAX); 
+// mid name
+if((gd.td.middle_name=(char **)malloc(sizeof(char *) * (gd.td.midcount + 2)))==NULL){exit(1);}
+if((gd.td.middle_id=(char *)malloc(sizeof(char)*(gd.td.midcount + 2)))==NULL){exit(1);}
+for(count = 0; count <= gd.td.midcount; count++){
+   if((gd.td.middle_name[count]=(char *)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
    gd.td.middle_id[count] = 0;
    }
 
@@ -56,12 +56,12 @@ int count;
 printf("FREE: malloc_set2_free():\n");
 #endif
 
-for(count = 0; count <= gd.td.tbufmax; count++){
+for(count = 0; count <= gd.td.tcount; count++){
    free(gd.td.mutex_name[count]);
    }
 
-for(count = 0; count <= B_MAX; count++){
-   free(gd.td.mutex_name[count]);
+for(count = 0; count <= gd.td.midcount; count++){
+   free(gd.td.middle_name[count]);
    }
 
 free(gd.td.fdstat);
