@@ -42,11 +42,7 @@ return 0;
 
 int opt_version(void)
 {
-#ifdef NET_SNMP_IN
-printf("------- %s for net-snmp -------\n", CL_VAR);
-#else
 printf("------- %s -------\n", CL_VAR);
-#endif
 
 printf("MAX THREAD              = %d(default)\n", B_LEN);
 printf("MAX process in thread   = %d(default)\n", B_MAX);
