@@ -16,9 +16,15 @@ extern struct scan_buf sb;
 /* ------------------ PATH CHECK ----------------- */
 int path_check(char *chA)
 {
-int bu;
+int bu, count, co;
 char ch[31][BUF_COM];
-int count = 0;
+count = 0;
+bu = 0;
+
+for(co = 0; co < 31; co++){
+   memset(ch[co], 0x00, BUF_COM);
+   }
+
 char * non = "NOT";
 char * sock_ipaddr="SOCK_IPADDR";
 char * sock_port="SOCK_PORT";
@@ -81,7 +87,6 @@ self_memcpy(ch[27], midump_filename_2, BUF_COM);
 self_memcpy(ch[28], dns_ip, BUF_COM);
 self_memcpy(ch[29], dns_ip2, BUF_COM);
 
-bu = 0;
 if(BUF_COM > strlen(chA)){
    for(count=1; count < 30; count++){
       if(0 == memcmp(chA, ch[count], (int)strlen(ch[count])+1)){
