@@ -5,6 +5,7 @@
 /* --- sitar.c --- */
 int safe_exit(char *);
 int signal_exit(void);
+int signal_errout(void);
 int check_alget(char *);
 int life_put(void);
 int start_neg(void);
@@ -22,6 +23,9 @@ int miname_dump(char *);
 int miname_install(void);
 int th_miname_dump(void);
 int midump_remove(char *);
+char mid_chserver(char *, int);
+char mid_remserver(char *, int);
+char mid_setserver(char *, int, int);
 
 /* --- confset.c --- */
 int conf_set(char *);
@@ -83,6 +87,7 @@ int time_format(char *, int *, int *, int *, int *, int *);
 /* --- swap_char.c --- */
 int swap_char(char *);
 
+char * scan_psql_command(char *, char *, char *, char *, char *, char *, int, int, int *, char *);
 
 char * cal_oid(char *, char *, int *, int *, char *, char *, int *, int);
 char * snmp_test(char *, char *, char *, char *, int *, int, int *, int);
@@ -90,4 +95,7 @@ int scan_snmp(struct scan_buf *);
 int ch_en(char);
 int cal4(int, int, char);
 
+// libc.so にあるが、string.h ではexternされているので宣言する。
+char *strcasestr (__const char *__haystack, __const char *__needle);
+
 
