@@ -30,10 +30,8 @@ extern pthread_mutex_t thread_mutex;
 //  scan_block はポート、コマンドのスレッド分岐先の関数になります
 void * scan_block(int count)
 {
-// char * tmp;
-// int co, stat, errcount, mucount, mutexid, middleid, interval, wtime_1, wtime_2, wtime_3, wtime_4, instat;
 int co, stat, errcount, testcount, mucount, mutexid, middleid, interval, instat, dstat, thread_co;
-char mid_stat;
+char mid_stat, midret;
 
 interval = (gd.bf.life_int + gd.bf.life_los + INT_PLUS);
 
@@ -46,7 +44,8 @@ errcount = 0;
 testcount = 0;
 stat = 0;
 dstat = 0;
-thread_co =0;
+thread_co = 0;
+midret = -3;
 
 // Pthread detachd このスレッドをデタッチします。
 // 元スレッドはこの関数の終わりを待ちません
@@ -204,62 +203,87 @@ for(co = 0; co < gd.td.tbufmax; co++){
 
                   if(0 < (int)strlen(pd->sb.ch_free4)){ 
 
-                     if(0 == self_memcmp(pd->sb.ch_free1, "MID")){ mid_stat = 1; }
-                     else if(0 == self_memcmp(pd->sb.ch_free1, "MIX")){ mid_stat = 2; }
-                     else{ mid_stat = 0; }
-
-
-                     #ifdef MID_BUG
-                     printf("MID_BUG: scan_block(1): %s <%d>\n", pd->sb.ch_free1, mid_stat);
-                     #endif
-
-
-
-
+                     if(0 == self_memcmp(pd->sb.ch_free1, "MID")){
+                        mid_stat = 1;
+                        }
+                     else if(0 == self_memcmp(pd->sb.ch_free1, "MIX")){
+                        mid_stat = 2;
+                        }
+                     else{
+                        mid_stat = 0;
+                        }
 
 
                      // mail 属性がmiddleな場合に、ブロック名をDBに登録します
                      // middleでない場合はブロック名の登録がある場合は消します。
-             //      pthread_mutex_lock(&mail_mutex);
                      safe_pthread_mutex_lock(&mail_mutex);
 
                      if(mid_stat > 0){   // MID か MIX な場合
+                        // ------- A -------
+                        // zither サーバ側にMIDのアカウントが登録済みかを確認する
+                        // 無かった場合は -1, 対応していないバージョンは -2を、通常は現状のカウント数 0<* を返す。
+                        //  -1 無い場合は新規で作る(0)、新規の場合はチェック
+                        //  -2 Zitherが対応していない場合は変数にチェック
+                        #ifdef MID_BUG
+                        printf("MID_BUG: scan_block(1): 鯖に確認にいってみる %s <%d>\n", pd->sb.ch_free1, mid_stat);
+                        #endif
+                        midret = mid_chserver(pd->sb.ch_free4, interval);
+
+
+
+
                         for(mucount = 0; mucount < gd.td.midcount; mucount++){
                            if(0 == self_memcmp(gd.td.middle_name[mucount], pd->sb.ch_free4)){
                               middleid = mucount;
-                              // MIDかMIXで名前が登録されているので、そのIDを返す
+                              /* MIDかMIXで名前が登録されているので、そのIDを返す */
                               #ifdef MID_BUG
                               printf("MID_BUG: scan_block(2): MID同じ名前のブロックが既に登録済みです <%s> mucount<%d><%s>count<%d><%d>\n",
                                 gd.td.middle_name[mucount], mucount, pd->sb.ch_free4, gd.td.middle_id[mucount], pd->sb.fdno);
                               #endif
 
+                              /* ------ A ------ */
+                              /* 新規の場合に限り、ローカルDBにある数を、Zitherがわに登録する。*/
+                              /* 通常このケースは無い */
+                              if(midret == -1){
+                                 #ifdef MID_BUG
+                                 printf("MID_BUG: scan_block(2,1): 鯖に登録なく、鯖を同期します <%s> mucount<%d><%s>count<%d><%d>\n",
+                                   gd.td.middle_name[mucount], mucount, pd->sb.ch_free4, gd.td.middle_id[mucount], pd->sb.fdno);
+                                 #endif
+                                 if( -1 == (mid_setserver(pd->sb.ch_free4, gd.td.middle_id[mucount], interval))){
+                                    fprintf(stderr,"MID_BUG: scan_block(): mid_setserver(): サーバ側MID設定に失敗しています\n");
+                                    }
+                                 }
+
                               break;
                               }
-                           } // for()
+                           } /* for() */
 
 
-                        if(middleid == -1){   // MIDやMIXだがIDが存在しなかった
+                        if(middleid == -1){   /* MIDやMIXだがIDが存在しなかった */
                            for(mucount = 0; mucount < gd.td.midcount; mucount++){
                               if(gd.td.middle_name[mucount][0] == (char)0x00){ 
                                  gd.td.middle_name[mucount] = safe_memcpy(gd.td.middle_name[mucount], pd->sb.ch_free4, BUF_MAX);
                                  gd.td.middle_id[mucount] = 0;
-                                 // 開いている場所を探して登録する
+                                 /* 開いている場所を探して登録する */
                                  #ifdef MID_BUG
                                  printf("MID_BUG: scan_block(3): MIDブロック新規に登録しました <%s> mucount<%d><%s>count<%d><%d>\n",
                                     gd.td.middle_name[mucount], mucount, pd->sb.ch_free4, gd.td.middle_id[mucount], pd->sb.fdno);
                                  #endif
 
                                  middleid = mucount;
+
                                  break;
                                  }
-                              } // for()
-                           if(mucount > gd.td.midcount){   // 開いている場所がないのでこれはエラー、普通ない、死ぬだろな？w
+                              } /* for() */
+                           if(mucount > gd.td.midcount){   /* 開いている場所がないのでこれはエラー、普通ない、死ぬだろな？w */
                               fprintf(stderr,"scan_block(): MID上限%dを越えたためブロックが登録出来ません mucount<%d> <%s>\n",
                                  gd.td.midcount, mucount, pd->sb.ch_free4);
                               }
                            }
 
                         }
+
+
                      else{   // MID や MIX でない場合
                         for(mucount = 0; mucount < gd.td.midcount; mucount++){
                            if(0 == self_memcmp(gd.td.middle_name[mucount], pd->sb.ch_free4)){
@@ -271,6 +295,18 @@ for(co = 0; co < gd.td.tbufmax; co++){
 
                               gd.td.middle_name[mucount] = null_free(gd.td.middle_name[mucount]);
                               gd.td.middle_id[mucount] = 0;
+
+                              // ------- B -------
+                              // Zitheサーバ側にもMIDアカウントを削除依頼する。
+                              #ifdef MID_BUG
+                              printf("MID_BUG: scan_block(): 鯖側の設定を消します <%s> mucount<%d> <%s> count<%d>\n",
+                                gd.td.middle_name[mucount], mucount, pd->sb.ch_free4, gd.td.middle_id[mucount]);
+                              #endif
+                              if( -1 == (mid_remserver(pd->sb.ch_free4, interval))){
+                                 fprintf(stderr,"MID_BUG: scan_block(): mid_remserver(): サーバ側MIDのID削除に失敗しています\n");
+                                 }
+
+
                               break;
                               }
                            } // for()
@@ -279,13 +315,23 @@ for(co = 0; co < gd.td.tbufmax; co++){
 
 
 
-
+                     // ------- A2 -------
+                     // もしもMID,MIXで、
+                     // Zitherが対応している場合で
+                     // Zither側にアカウントがあった場合で。(0 < * )
+                     // Zitherに問い合わせたカウントにローカルDBのカウントをあわせてしまう。
+                     // Zitherにアカウントが無いか、未対応のバージョンの場合は何もしない。
+                     if(midret > -1){
+                        gd.td.middle_id[mucount] = midret;
+                        #ifdef MID_BUG
+                        printf("MID_BUG: can_block(): ローカル側のカウントを鯖側のカウントで上書きしました\n");
+                        #endif
+                        }
 
 
 
                      // スレッドの排他処理についての
                      // 同じ監視ブロックが動いている場合はfor()から抜けます、スレッド排他処理しています 
-        //           pthread_mutex_lock(&name_mutex);
 
                      safe_pthread_mutex_lock(&name_mutex);
                      for(mucount = 0; mucount < gd.td.tcount; mucount++){
@@ -480,7 +526,6 @@ for(co = 0; co < gd.td.tbufmax; co++){
                   // mail送信属性を判断し、MIDの場合は ONかOFFに判断する。
                   if(mutexid == 0){
 
-      //             pthread_mutex_lock(&mail_mutex);
                      safe_pthread_mutex_lock(&mail_mutex);
                      if(mid_stat > 0 && middleid > -1){
 
@@ -634,7 +679,6 @@ forloopout :;
 
 
 if(mutexid == 0){
-// pthread_mutex_lock(&name_mutex);
    safe_pthread_mutex_lock(&name_mutex);
    #ifdef MUTEX_BUG
    printf("MUTEX: scan_block(2): 登録ブロック名を消しました <%s> mucount<%d>\n",
@@ -685,14 +729,12 @@ if(sa.buf_err[pd->sb.fdno] == 1){
 if(mutexid == 0){
 
    // ERR が観測された場合のプロトコルセット
-// pthread_mutex_lock(&break_mutex);
    safe_pthread_mutex_lock(&break_mutex);
    if(gd.bf.break_count == 0 && (errcount - testcount) > 0){                 // <----- gd???
 
       if(1 < strlen(pd->sb.scan_all) && (char)0x0a != pd->sb.scan_all[0]){
 
          if(mid_stat > 0 && middleid > -1){    // MID か MIX　な場合
-//          pthread_mutex_lock(&mail_mutex);
             safe_pthread_mutex_lock(&mail_mutex);
 
             if(gd.td.middle_id[middleid] <= 3){
@@ -707,6 +749,20 @@ if(mutexid == 0){
             #endif
 
             pthread_mutex_unlock(&mail_mutex);
+ 
+           // ------ C -------
+            // Zitherが対応している場合で
+            // Zither サーバ側に現在のカウントを反映する。
+            if(midret > -2){
+               #ifdef MID_BUG
+               printf("MID_BUG: scan_block(): 鯖側に現在のカウントを登録 <%s> middleid<%d> id<%d> co<%d>fd<%d>\n",
+                   gd.td.middle_name[middleid], middleid, gd.td.middle_id[middleid], co, pd->sb.fdno);
+               #endif
+               if( -1 == (mid_setserver(pd->sb.ch_free4, gd.td.middle_id[middleid], interval))){
+                  fprintf(stderr,"MID_BUG: scan_block(): mid_setserver(2): サーバ側MID設定に失敗しています\n");
+                  }
+               } 
+
             }
 
          swap_mem(pd->sb.scan_all, '\n', (char)0x01);
@@ -741,15 +797,13 @@ if(mutexid == 0){
    else{
       if(1 < strlen(pd->sb.scan_all) && (char)0x0a != pd->sb.scan_all[0]){
 
-//       pthread_mutex_lock(&mail_mutex);
-         safe_pthread_mutex_lock(&mail_mutex);
 
+         safe_pthread_mutex_lock(&mail_mutex);
          if(mid_stat == 1 && middleid > -1){    // MID なばあい
             if(gd.td.middle_id[middleid] > 1){
                gd.td.middle_id[middleid]--;
                }
             if(gd.td.middle_id[middleid] == 3){
-               gd.td.middle_id[middleid] = 0;
                // MIDが正常監視に戻ったのでとりあえず名前を消す。
                gd.td.middle_id[middleid] = 0;
                }
@@ -758,6 +812,20 @@ if(mutexid == 0){
             printf("MID_BUG: scan_block(): stat 1 エラーを観測しませんでした <%s> middleid<%d> id<%d> co<%d>fd<%d>\n",
                gd.td.middle_name[middleid], middleid, gd.td.middle_id[middleid], co, pd->sb.fdno);
             #endif
+
+            // ------ C -------
+            // Zitherが対応している場合で
+            // Zither サーバ側に現在のカウントを反映する。
+            if(midret > -2){
+               #ifdef MID_BUG
+               printf("MID_BUG: scan_block(): 鯖側に現在のカウントを登録 <%s> middleid<%d> id<%d> co<%d>fd<%d>\n",
+                  gd.td.middle_name[middleid], middleid, gd.td.middle_id[middleid], co, pd->sb.fdno);
+               #endif
+               if( -1 == (mid_setserver(pd->sb.ch_free4, gd.td.middle_id[middleid], interval))){
+                  fprintf(stderr,"MID_BUG: scan_block(): mid_setserver(3): サーバ側MID設定に失敗しています\n");
+                  }
+               }
+
             }
          else if(mid_stat == 2 && middleid > -1){   // MIX な場合
             #ifdef MID_BUG
@@ -766,12 +834,26 @@ if(mutexid == 0){
             #endif
             // MIXが正常監視に戻ったのでとりあえず名前を消す。
             gd.td.middle_id[middleid] = 0;
-            }
-         else{
-            }
 
+            // ------ C -------
+            // Zitherが対応している場合で
+            // Zither サーバ側に現在のカウントを反映する。
+            if(midret > -2){
+               #ifdef MID_BUG
+               printf("MID_BUG: scan_block(): 鯖側に現在のカウントを登録 <%s> middleid<%d> id<%d> co<%d>fd<%d>\n",
+                  gd.td.middle_name[middleid], middleid, gd.td.middle_id[middleid], co, pd->sb.fdno);
+               #endif
+               if( -1 == (mid_setserver(pd->sb.ch_free4, gd.td.middle_id[middleid], interval))){
+                  fprintf(stderr,"MID_BUG: scan_block(): mid_setserver(4): サーバ側MID設定に失敗しています\n");
+                  }
+               }
+
+            }
+         else{                                      // MID,MIDでは無い場合
+            }
          pthread_mutex_unlock(&mail_mutex);
 
+
          if(testcount > 0){    // ブロック内での観測エラーがすべてTESTモードの場合
 
             swap_mem(pd->sb.scan_all, '\n', (char)0x01);
@@ -831,7 +913,6 @@ printf("FREE: single scan_block(): scan_malloc_free(): pd\n");
 printf("MALLOC: scan_block(2): scan_malloc_free(pd): free(pd)\n");
 #endif
 
-//pthread_mutex_lock(&fdstat_mutex);
 safe_pthread_mutex_lock(&fdstat_mutex);
 #ifdef SCAN_BUG
 printf("THREAD: scan_block(): 監視ブロックから抜けます。 no<%d> data<%d>\n",
