@@ -182,7 +182,8 @@ if('#' != pd->sb.swap_2[0]){
                fprintf(stderr,"MONITOR 1: %s: %s: %s: %s:\n",
                  pd->sb.ch_tool, pd->sb.ch_prot, pd->sb.ch_free1, pd->sb.ch_free4);
                #endif 
-               scan_port(&pd->sb);
+//             scan_port(&pd->sb);
+               scan_port(pd);
                }
             else if(0 == self_memcmp(pd->sb.ch_tool, "COMAND")){
                #ifdef MONITOR_BUG
