@@ -97,7 +97,8 @@ char * ip_addr = ipx;
 char pas[BUF_URL];
 char * url_pass = pas;
 char * ip_addr2 = ipa2;
-char ntopbuff[256];
+char ntp[IP_LEN];
+char * ntopbuff = ntp;
 
 struct sockaddr_in send_addr;
 struct timeval tv;
@@ -152,7 +153,7 @@ if(0 == (int)send_addr.sin_addr.s_addr || resoip == (int)NULL){
    }
 
 // ip_addr2 = inet_ntoa(send_addr.sin_addr);
-ip_addr2 = inet_ntop(AF_INET, &send_addr.sin_addr, ntopbuff, sizeof(ntopbuff));
+ip_addr2 = (char *)inet_ntop(AF_INET, &send_addr.sin_addr, ntopbuff, IP_LEN);
 
 #ifdef ICMP_BUG
 printf("ICMP: scan_icmp(1): ICMP host<%s> ip<%s>\n", ip_addr, ip_addr2);
@@ -222,7 +223,7 @@ while(1){
          if(rtt > (timeout * coe)){
             backdata=safe_sprintf(backdata,BUF_MAX,"%s :RTT=%7.4fms TIMEOUT=%dms %s",
 //          inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)),
-            inet_ntop(AF_INET, (struct in_addr *)(long int)&(ip->ip_src.s_addr), ntopbuff, sizeof(ntopbuff)),
+            (char *)inet_ntop(AF_INET, (struct in_addr *)(long int)&(ip->ip_src.s_addr), ntopbuff, IP_LEN),
             rtt, (timeout * coe), ICMP_5);
             #ifdef ICMP_BUG
             printf("ICMP: scan_icmp(5): RECV RAW DATA NG! %s\n",  backdata);
@@ -235,7 +236,7 @@ while(1){
          else if(rtt <= (timeout * coe)){
             backdata=safe_sprintf(backdata,BUF_MAX,"%s :RTT=%7.4fms TIMEOUT=%dms %s",
 //          inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr))
-            inet_ntop(AF_INET, (struct in_addr *)(long int)&(ip->ip_src.s_addr), ntopbuff, sizeof(ntopbuff)),
+            (char *)inet_ntop(AF_INET, (struct in_addr *)(long int)&(ip->ip_src.s_addr), ntopbuff, IP_LEN),
             rtt, (timeout * coe), ICMP_6);
             #ifdef ICMP_BUG
             printf("ICMP: scan_icmp(6): RECV RAW DATA OK! %s\n", backdata);
@@ -247,7 +248,7 @@ while(1){
          else{
             backdata=safe_sprintf(backdata,BUF_MAX,"%s :RTT=%7.4fms TIMEOUT=%dms %s",
 //          inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)),
-            inet_ntop(AF_INET, (struct in_addr *)(long int)&(ip->ip_src.s_addr), ntopbuff, sizeof(ntopbuff)),
+            (char *)inet_ntop(AF_INET, (struct in_addr *)(long int)&(ip->ip_src.s_addr), ntopbuff, IP_LEN),
             rtt, (timeout * coe), ICMP_5);
             #ifdef ICMP_BUG
             printf("ICMP: scan_icmp(5): RTT err! %s\n",  backdata);
@@ -271,7 +272,7 @@ while(1){
       else if(icmp->icmp_type == ICMP_UNREACH){
          backdata=safe_sprintf(backdata,BUF_MAX,"%s :RTT=%7.4fms %s",
 //          inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)),
-            inet_ntop(AF_INET, (struct in_addr *)(long int)&(ip->ip_src.s_addr), ntopbuff, sizeof(ntopbuff)),
+            (char *)inet_ntop(AF_INET, (struct in_addr *)(long int)&(ip->ip_src.s_addr), ntopbuff, IP_LEN),
             tv.tv_sec*1000.0 + tv.tv_usec/1000.0, ICMP_7);
          #ifdef ICMP_BUG
          printf("ICMP: scan_icmp(8): RECV RAW %s type<%d>\n", backdata, icmp->icmp_type);
@@ -283,7 +284,7 @@ while(1){
       else{
          backdata=safe_sprintf(backdata,BUF_MAX,"%s :RTT=%7.4fms %s",
 //          inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)),
-            inet_ntop(AF_INET, (struct in_addr *)(long int)&(ip->ip_src.s_addr), ntopbuff, sizeof(ntopbuff)),
+            (char *)inet_ntop(AF_INET, (struct in_addr *)(long int)&(ip->ip_src.s_addr), ntopbuff, IP_LEN),
             tv.tv_sec*1000.0 + tv.tv_usec/1000.0, ICMP_4);
          #ifdef ICMP_BUG
          printf("ICMP: scan_icmp(10): RECV RAW %s type<%d>\n", backdata, icmp->icmp_type);
