@@ -125,8 +125,8 @@ else if((self_memcmp(pd->sb.ch_prot,"MYSQL")) == 0){
 
          }
       #ifdef MYSQL_BUG
-      printf("MYSQL_BUG: scan_mysql_connect(): %d, %s, <%s>, %d, %d, %d, %s\n"
-        ,pd->db.port, pd->sb.ch_host, pd->sb.ch_info, pd->db.timeout, lim, ret, pd->sb.ch_plai);
+      printf("port=%d: pass=%s: user=%s: db=%s: Query=%s: %s\n",
+         pd->db.port, pd->db.passwd, pd->db.username, pd->db.database, pd->sb.ch_com, MYSQL_2);
       #endif
       }
 
@@ -135,6 +135,48 @@ else if((self_memcmp(pd->sb.ch_prot,"MYSQL")) == 0){
 
 
 
+
+
+else if((self_memcmp(pd->sb.ch_prot,"PGSQL")) == 0){
+
+   pd->sb.ch_info = db_data_delim(pd->sb.ch_info, pd->sb.ch_host, pd, &ret);
+
+   if(ret > -1){
+
+      if(pd->db.port == 0){
+         pd->db.port = pd->sb.port;
+         }
+      if(pd->db.timeout == 0){
+         pd->db.timeout = pd->sb.timeout;
+         }
+
+      pd->sb.ch_info = scan_psql_command(pd->sb.ch_info,
+                         pd->sb.ch_com, pd->db.server, pd->db.username, pd->db.passwd,
+                         pd->db.database, pd->db.port, pd->db.timeout, &ret, pd->sb.ch_plai);
+
+      if(0 == (int)strlen(pd->sb.ch_info)){
+         if(ret > -1){
+            pd->sb.ch_info=safe_sprintf(pd->sb.ch_info, BUF_MAX,"port=%d: pass=%s: user=%s: db=%s: Query=%s: %s\n",
+               pd->db.port,pd->db.passwd, pd->db.username, pd->db.database, pd->sb.ch_com, PGSQL_1);
+            }
+         else{
+            pd->sb.ch_info=safe_sprintf(pd->sb.ch_info, BUF_MAX,"port=%d: pass=%s: user=%s: db=%s: Query=%s: %s\n",
+               pd->db.port, pd->db.passwd, pd->db.username, pd->db.database, pd->sb.ch_com, PGSQL_2);
+            }
+
+         }
+      #ifdef PGSQL_BUG
+      printf("port=%d: pass=%s: user=%s: db=%s: Query=%s: %s\n",
+          pd->db.port,pd->db.passwd, pd->db.username, pd->db.database, pd->sb.ch_com, PGSQL_1);
+      #endif
+      }
+
+   db_malloc_null(pd);
+   }
+
+
+
+
 else if((self_memcmp(pd->sb.ch_prot,"SMTP")) == 0){
    pd->sb.ch_info = scan_smtp_connect(pd->sb.port, pd->sb.ch_host, pd->sb.ch_info,pd->sb.timeout,&ret);
    if(0 == (int)strlen(pd->sb.ch_info)){
