@@ -84,12 +84,14 @@ fd_set rfds;
 struct timeval tv;
 char recvd[BUF_LEN];
 char sendd[BUF_LEN];
+char bu[IP_LEN];
 char * recvdata = recvd;
 char * senddata = sendd;
-char buff[256];
+char * buff = bu;
 
 memset(recvdata, 0x00, BUF_LEN);
 memset(senddata, 0x00, BUF_LEN);
+memset(buff, 0x00, IP_LEN);
 
 // struct buf_data bd;
 
@@ -133,7 +135,7 @@ if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
    }
 
 // ip_addr = inet_ntoa(my_addr.sin_addr);
-ip_addr = inet_ntop(AF_INET, &my_addr.sin_addr, buff, sizeof(buff));
+ip_addr = (char *)inet_ntop(AF_INET, &my_addr.sin_addr, buff, IP_LEN);
 
 #ifdef SMTP_BUG
 printf("SMTP: scan_smtp_connect(0): %s %s %d\n", url_dom, ip_addr, port);
