@@ -33,7 +33,8 @@ char ip[BUF_URL];
 char * ip_addr = ip;
 char pas[BUF_URL];
 char * url_pass = pas;
-char buff[256];
+char bu[IP_LEN];
+char * buff = bu;
 
 int sk, re, retval, arglen, port2, resolv_ret;
 unsigned long resoip;
@@ -48,6 +49,7 @@ resolv_ret = 0;
 
 memset(ip_addr, 0x00, BUF_URL);
 memset(url_pass, 0x00, BUF_URL);
+memset(buff, 0x00, IP_LEN);
 
 // portの設定よりもURLに含まれるポートを優先する
 port2 = urldompass_port(url_data, ip_addr, url_pass, strlen(url_data));
@@ -99,7 +101,7 @@ if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
    }
 
 // ip_addr2 = inet_ntoa(my_addr.sin_addr);
-ip_addr2 = inet_ntop(AF_INET, &my_addr.sin_addr, buff, sizeof(buff));
+ip_addr2 = (char *)inet_ntop(AF_INET, &my_addr.sin_addr, buff, IP_LEN);
 
 #ifdef TCP_BUG
 printf("TCP: scan_tcp_connetc(3): start TCPCHECK host<%s> ip<%s>\n", ip_addr2, ip_addr);
