@@ -37,13 +37,14 @@ char sendd[BUF_LEN];
 char ipa[IP_LEN];
 char dom[BUF_URL];
 char pass[BUF_URL];
+char bu[IP_LEN];
 
 char * ip_addr = ipa;
 char * url_dom = dom;
 char * url_pass = pass;
 char * recvdata = recvd;
 char * senddata = sendd;
-char buff[256];
+char * buff = bu;
 
 dcount = 0;
 arglen = sizeof(int);
@@ -55,6 +56,7 @@ memset(senddata, 0x00, BUF_LEN);
 memset(ip_addr, 0x00, IP_LEN);
 memset(url_dom, 0x00, BUF_URL);
 memset(url_pass, 0x00, BUF_URL);
+memset(buff, 0x00, IP_LEN);
 
 // portの設定よりもURLに含まれるポートを優先する
 stat = urldompass_port(url_data, url_dom, url_pass, strlen(url_data)); 
@@ -111,7 +113,7 @@ if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
    }
 
 // ip_addr = inet_ntoa(my_addr.sin_addr);
-ip_addr = inet_ntop(AF_INET, &my_addr.sin_addr, buff, sizeof(buff));
+ip_addr = (char *)inet_ntop(AF_INET, &my_addr.sin_addr, buff, IP_LEN);
 
 #ifdef URL_BUG
 printf("URL_BUG: scan_url_connect(3): %s\n", ip_addr);
