@@ -59,7 +59,8 @@ char * ssl_senddata;
 char * backdata;
 char * swapdata = swa;
 char * recvdata = rec;
-char buff[256];
+char bu[IP_LEN];
+char * buff = bu;
 
 extern char *optarg;
 
@@ -137,7 +138,7 @@ while((i=getopt(argc,argv,"a:p:t:c:u:v:d:z"))!= EOF){
                    }
               break;
 
-      default : printf("scanssl-%s $scanssl -p <port> -t <timout> -c <cert time limmit> -u <https://URL>\n",VERSION);
+      default : printf("scanssl-%s $scanssl -d <DNS IP> -p <port> -t <timout> -c <cert time limmit> -u <https://URL>\n",VERSION);
               free(senddata);
               free(url_data);
               free(dns_data);
@@ -211,7 +212,7 @@ if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
    }
 
 // ip_addr = inet_ntoa(my_addr.sin_addr);
-ip_addr = inet_ntop(AF_INET, &my_addr.sin_addr, buff, sizeof(buff));
+ip_addr = (char *)inet_ntop(AF_INET, &my_addr.sin_addr, buff, IP_LEN);
 
 #ifdef SSL_BUG
 printf("SSL_BUG: scanssl(3): %s\n", ip_addr);
