@@ -38,7 +38,8 @@ int main(int argc, char * argv[])
 {
 // struct addrinfo hints;
 int tret;
-pthread_t t1, t2, t3, t4;
+pthread_t t1, t3, t4;
+// pthread_t t2;
 errno = 0;
 
 // struct sockaddr_in mygd_addr;
@@ -72,11 +73,12 @@ private_malloc_set();
 #endif
 
 // シグナルの設定
-signal(SIGINT, signal_exit);
-signal(SIGKILL, signal_exit);
-signal(SIGQUIT, signal_exit);
-signal(SIGHUP, signal_exit);
-// signal(SIGTERM, signal_exit);  // BSDの為
+signal(SIGINT, (void *)signal_exit);
+signal(SIGKILL, (void *)signal_exit);
+signal(SIGQUIT, (void *)signal_exit);
+signal(SIGHUP, (void *)signal_exit);
+signal(SIGPIPE, (void *)signal_errout);
+// signal(SIGTERM, (void *)signal_exit);  // BSDの為
 
 gd.bf.my_pid = (int)getpid();
 
@@ -88,11 +90,9 @@ gd.bf.my_pid = (int)getpid();
 memset(&gd.ip.hints, 0, sizeof(gd.ip.hints));
 
 // サーバに接続
-//if((socket_connect(&gd.ip.mygd_addr, gd.ip.port, gd.ip.ip_addr, &gd.ip.sk)) < 0){
 if((socket_connect46(&gd.ip.hints, gd.ip.ip_addr, gd.ip.port_s, &gd.ip.sk)) < 0){
    fprintf(stderr,"main(): Not connection <1> %s %d\n", gd.ip.ip_addr, gd.ip.port);
    sleep(10);
-// if((socket_connect(&gd.ip.mygd_addr, gd.ip.port2, gd.ip.ip2_addr, &gd.ip.sk)) < 0){
    if((socket_connect46(&gd.ip.hints, gd.ip.ip2_addr, gd.ip.port2_s, &gd.ip.sk)) < 0){
       fprintf(stderr,"main(): Not connection <2> %s %d\n", gd.ip.ip2_addr, gd.ip.port2);
       safe_exit("main(): socket connect err exit \n");
@@ -110,7 +110,6 @@ gd.bf.break_count = 0;
 tret = 0;
 
 // メール完結処理用のバッファーを復元
-//pthread_mutex_lock(&name_mutex);
 safe_pthread_mutex_lock(&name_mutex);
 miname_install();
 pthread_mutex_unlock(&name_mutex);
