@@ -15,6 +15,10 @@
     #include<netdb.h>
   #endif
 
+  #ifndef _PTHREAD_H_
+    #include<pthread.h>
+  #endif
+
 
 
   // チューニングが必要な場合OS側の調整が必要になるかもしれません。
