@@ -84,7 +84,7 @@ if(ustat == 0 && astat != 0 && cgstat != 0){
   #ifdef LOG_OUT
   safe_pthread_mutex_lock(&con_mutex);
   log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data,
-   "200 OK It doesn't write it.", gd.ms.inip_addr[pd->rec.fdno]);
+   "200 OK It doesn't write it.", (unsigned char *)gd.ms.inip_addr[pd->rec.fdno]);
   pthread_mutex_unlock(&con_mutex);
   #endif
   }
@@ -93,7 +93,7 @@ else{
   #ifdef LOG_OUT
   safe_pthread_mutex_lock(&con_mutex);
   log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data,
-    "500 NG BAT command.", gd.ms.inip_addr[pd->rec.fdno]);
+    "500 NG BAT command.", (unsigned char *)gd.ms.inip_addr[pd->rec.fdno]);
   pthread_mutex_unlock(&con_mutex);
   #endif
   } 
