@@ -395,6 +395,30 @@ if(pri < 3){
            info);
          }
 
+      else if(0 == self_memcmp(prot, "PGSQL")){
+         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+           MAIL_PGSQL_11,
+           kanshi,
+           MAIL_PGSQL_12,
+           pri_data,
+           MAIL_PGSQL_13,
+           prot,
+           MAIL_PGSQL_14,
+           host,
+           MAIL_PGSQL_15,
+           com,
+           MAIL_PGSQL_16,
+           port,
+           MAIL_PGSQL_17,
+           timeout,
+           MAIL_PGSQL_18,
+           free1,
+           MAIL_PGSQL_19,
+           data,
+           MAIL_PGSQL_20,
+           info);
+         }
+
 
 
       else if(0 == self_memcmp(prot, "URL")){
@@ -560,6 +584,32 @@ if(pri < 3){
          }
 
 
+      else if(0 == self_memcmp(prot, "PGSQL")){
+         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+           MAIL_PGSQL_21,
+           kanshi,
+           MAIL_PGSQL_22,
+           pri_data,
+           MAIL_PGSQL_23,
+           prot,
+           MAIL_PGSQL_24,
+           host,
+           MAIL_PGSQL_25,
+           com,
+           MAIL_PGSQL_26,
+           port,
+           MAIL_PGSQL_27,
+           timeout,
+           MAIL_PGSQL_28,
+           free1,
+           MAIL_PGSQL_29,
+           data,
+           MAIL_PGSQL_30,
+           info);
+         }
+
+
+
       else if(0 == self_memcmp(prot, "URL")){
 //       swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
          swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
