@@ -11,16 +11,17 @@
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
-extern  MYSQL mysql_buf;
-extern  MYSQL * my_conn;
-extern  MYSQL_RES * my_result;
+//extern  MYSQL mysql_buf;
+//extern  MYSQL * my_conn;
+//extern  MYSQL_RES * my_result;
 
+extern  global_data_t gd;
 
 int mysqlconnect(char * mysql_server, char * mysql_username, char * mysql_password, char * mysql_db)
 {
 // mysql の初期化
-if(mysql_init(&mysql_buf) == NULL){
-   fprintf(stderr, "mysqlconnect(0): %s\n", mysql_error(&mysql_buf));
+if(mysql_init(&gd.mysql.mysql_buf) == NULL){
+   fprintf(stderr, "mysqlconnect(0): %s\n", mysql_error(&gd.mysql.mysql_buf));
    return (-1);
    }
 
@@ -29,7 +30,7 @@ printf("MYSQL_DEBUG: mysqlconnect(1): %s\n", "mysqlの初期化成功");
 #endif
 
 // mysql への接続
-my_conn = mysql_real_connect(&mysql_buf,
+gd.mysql.my_conn = mysql_real_connect(&gd.mysql.mysql_buf,
                            mysql_server,
                            mysql_username,
                            mysql_password,
@@ -43,8 +44,8 @@ printf("MYSQL_DEBUG: mysqlconnect(2): %s\n", "mysqlのコネクション成功")
 #endif
 
 // mysql に接続出来たかの確認
-if(my_conn == NULL){
-   fprintf(stderr, "mysqlconnect(3): %s\n", mysql_error(&mysql_buf));
+if(gd.mysql.my_conn == NULL){
+   fprintf(stderr, "mysqlconnect(3): %s\n", mysql_error(&gd.mysql.mysql_buf));
    return (-1);
    }
 
