@@ -51,11 +51,12 @@ return 0;
 
 int opt_version(void)
 {
+printf("------- zither %s\n", CL_VAR);
 #ifdef POSTGRES_IN
-printf("------- %s for postgreSQL -------\n", CL_VAR);
+printf("------- for postgreSQL\n");
 #endif
 #ifdef MYSQL_IN
-printf("------- %s for mysql -------\n", CL_VAR);
+printf("------- for mysql\n");
 #endif
 printf("     -c /*/   config file name\n");
 printf("     -n /*/   nego file name\n");
