@@ -48,6 +48,12 @@ int print_conf(void)
    fprintf(stdout,"-- SIG_FILENAME   (mail signature list file)   = %s\n",gd.sig.sig_filename);
    fprintf(stdout,"-- SIG_INTERVAL   (mail signature set interval)= %d\n",gd.sig.sig_interval);
    #endif
+
+   fprintf(stdout,"-- MIDUMP_FILE    (mid tmp file 1)             = %s\n", gd.fi.midump_filename);
+   fprintf(stdout,"-- MIDUMP_FILE_2  (mid tmp file 2)             = %s\n", gd.fi.midump_filename_2);
+   fprintf(stdout,"-- MID_MAX        (mid user max)               = %d\n", gd.td.midcount);
+   fprintf(stdout,"-- MID_INT        (mid interval sec)           = %d\n", gd.td.midint);
+
    fprintf(stdout,"Version %s\n", CL_VAR);
 
 return 0;
