@@ -19,6 +19,7 @@ int mysqlexec_select(char *);
 
 
 int malloc_set(void);
+int malloc_free(void);
 int malloc_set2(void);
 int private_malloc_set(private_data_t *);
 int private_malloc_free(private_data_t *);
@@ -74,6 +75,7 @@ int com_check(char * chCOM);
 
 int safe_exit(char *);
 int signal_exit(void);
+int signal_errout(void);
 
 
 
@@ -108,10 +110,14 @@ int bat_logi(private_data_t *);
 int slget_logi(private_data_t *);
 int alget_logi(private_data_t *);
 int neg_logi(private_data_t *);
-
-
-
-
+// MID 
+int midget_logi(private_data_t *);
+int midremove_logi(private_data_t *);
+int midset_logi(private_data_t *);
+int th_miname_dump(void);
+int miname_install(void);
+int midump_remove(char *);
+int miname_dump(char *);
 
 
 
