@@ -18,18 +18,18 @@
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
-#ifdef POSTGRES_IN
-  #include<libpq-fe.h>
-  PGconn * conn = 0;
-  PGresult * res;
-#endif
+//#ifdef POSTGRES_IN
+//  #include<libpq-fe.h>
+//  PGconn * conn = 0;
+//  PGresult * res;
+//#endif
 
-#ifdef MYSQL_IN
-  #include<mysql.h>
-  MYSQL mysql_buf;
-  MYSQL * my_conn = 0;
-  MYSQL_RES * my_result;
-#endif
+//#ifdef MYSQL_IN
+//  #include<mysql.h>
+//  MYSQL mysql_buf;
+//  MYSQL * my_conn = 0;
+//  MYSQL_RES * my_result;
+//#endif
 
 
 global_data_t gd;
@@ -44,9 +44,12 @@ pthread_t t1;
 #ifdef SIGNATURE_MODE
 pthread_t t2;
 #endif
+
+pthread_t t3;
+
 long int fdcount;
 int tret;
-int error;
+// int error;
 int i;
 int pt;
 int retval;
@@ -63,13 +66,18 @@ tret = 0;
 
 pthread_mutex_init(&sig_mutex, NULL);
 pthread_mutex_init(&stat_mutex, NULL);
+pthread_mutex_init(&name_mutex, NULL);
 
-signal(SIGINT, signal_exit);
-signal(SIGKILL, signal_exit);
-signal(SIGQUIT, signal_exit);
-signal(SIGHUP, signal_exit);
+signal(SIGINT, (void *)signal_exit);
+signal(SIGKILL, (void *)signal_exit);
+signal(SIGQUIT, (void *)signal_exit);
+signal(SIGHUP, (void *)signal_exit);
+signal(SIGPIPE, (void *)signal_errout);
 // signal(SIGTERM, signal_exit);  // BSDの為
 
+gd.td.midcount = B_MID;   // mid max
+gd.td.midint = MID_INT;   // mid auto dump interval
+
 malloc_set();
 set_data();
 optin(argc, argv);
@@ -117,24 +125,6 @@ printf("MYSQL_DEBUG: zither.c: MYSQL CONNECTION STATUS <%d>\n", gd.mysql.stat);
 #endif
 
 
-// client stop checker thread 
-if((tret = pthread_create( &t1, NULL, (void *)clockfile_check, NULL)) != 0){
-   fprintf(stderr,"zither.c: main(0): t1 pthread_create %d\n", tret);
-   }
-
-#ifdef SIGNATURE_MODE
-// mail sign check 
-if((tret = pthread_create( &t2, NULL, (void *)mailsigfile_check, NULL)) != 0){
-   fprintf(stderr,"zither.c: main(1): t2 pthread_create %d\n", tret);
-   }
-#endif
-
-
-
-
-
-
-
 // IPにポート番号をバインド
 memset(&gd.ms.hints, 0, sizeof(gd.ms.hints));
 
@@ -167,6 +157,31 @@ for(i = 0; i < gd.ms.smax; i++){
    }
 
 
+
+
+// メール完結処理用のバッファーを復元
+safe_pthread_mutex_lock(&name_mutex);
+miname_install();
+pthread_mutex_unlock(&name_mutex);
+
+// client stop checker thread 
+if((tret = pthread_create( &t1, NULL, (void *)clockfile_check, NULL)) != 0){
+   fprintf(stderr,"zither.c: main(0): t1 pthread_create %d\n", tret);
+   }
+
+#ifdef SIGNATURE_MODE
+// mail sign check 
+if((tret = pthread_create( &t2, NULL, (void *)mailsigfile_check, NULL)) != 0){
+   fprintf(stderr,"zither.c: main(1): t2 pthread_create %d\n", tret);
+   }
+#endif
+
+// MIDネームリスト自動生成スレッドの生成
+if((tret = pthread_create( &t3, NULL, (void *)th_miname_dump, NULL)) != 0){
+   fprintf(stderr,"zither.c pthread_create(1): %d %d\n",tret, errno);
+   }
+
+
 // こねくしょんの受付無限ループ
 for(;;){
 
@@ -199,7 +214,7 @@ for(;;){
          for(i = 0; i < gd.ms.smax; i++){
             if(FD_ISSET(gd.ms.ss[i], &gd.ms.rfd)){
                gd.ms.fromlen = sizeof(gd.ms.from);
-               gd.ms.sk[fdcount] = accept(gd.ms.ss[i], (struct sockaddr *)&gd.ms.from, &gd.ms.fromlen);
+               gd.ms.sk[fdcount] = accept(gd.ms.ss[i], (struct sockaddr *)&gd.ms.from, (socklen_t *)&gd.ms.fromlen);
                // acceptで得たFDが0より小さい（異常）
                if(gd.ms.sk[fdcount] < 0){
                   printf("ip addr %s sock id = %d  proto Version = %d \n",
@@ -254,13 +269,16 @@ for(;;){
    }
 
 
-fprintf(stderr,"通常ここには到達しない\n");
+fprintf(stderr,"まあ通常ここには到達しないね\n");
 
 
 pthread_join( t1, NULL);
 #ifdef SIGNATURE_MODE
 pthread_join( t2, NULL);
 #endif
+pthread_join( t3, NULL);
+
+malloc_free();
 
 /* --- It doesn't reach. ---*/
 close(gd.ms.ls);
